import boto3
import click


def display_aws_profile_menu(available_profiles):
    profile_choices = list(map(str, range(1, len(available_profiles) + 1)))
    profile_choice_num = 1

    click.echo("\nWhich AWS profile do you want to use?\n")

    for profile in available_profiles:
        msg = str(profile_choice_num) + " - " + profile
        click.echo("\t" + msg)
        profile_choice_num = profile_choice_num + 1

    profile_choice = click.prompt("\nProfile", type=click.Choice(
        profile_choices), show_choices=False)
    return available_profiles[int(profile_choice) - 1]


def get_boto3_session(profile, region):
    return boto3.Session(profile_name=profile, region_name=region)


def select_aws_profile():
    available_profiles = boto3.session.Session().available_profiles
    aws_profile_choice = display_aws_profile_menu(available_profiles)
    return aws_profile_choice



import os
from setuptools import find_packages, setup

with open(os.path.join(os.path.dirname(__file__), "README.md")) as readme:
    README = readme.read()


def read_requirements():
    with open("requirements.txt", "r") as req:
        content = req.read()
        requirements = content.split("\n")

    return requirements


setup(
    name="avacli",
    version="3.0",
    packages=['ava'],
    include_package_data=True,
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/ZakHargz/ava-cli",
    author="Zak Hargreaves",
    author_email="zak@hargreaves.xyz",
    install_requires=read_requirements(),
    entry_points="""
        [console_scripts]
        ava=ava.cli:cli
    """,
    classifiers=[
        'Development Status :: 4 - Beta',
        'Programming Language :: Python :: 3.8',
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
    ],
)




import click
import boto3
import os
from ava.utilities import display_aws_profile_menu, get_boto3_session, select_aws_profile
from rich import box
from rich.console import Console
from rich.table import Table
from pathlib import Path

console = Console()
BOTO3_SESSION = None


@click.group()
@click.option('--profile')
@click.option('--region', default='eu-west-1')
@click.pass_context
def cli(ctx, profile, region):
    """
    Welcome to Ava!
    """
    if not (profile):
        profile = select_aws_profile()

    global BOTO3_SESSION
    BOTO3_SESSION = get_boto3_session(profile=profile, region=region)


@cli.command(name='ec2')
@click.pass_obj
def return_list_of_instances(ctx):
    """
    List EC2 instances and SSM status
    """
    ec2_client = BOTO3_SESSION.client('ec2')
    ssm_client = BOTO3_SESSION.client('ssm')
    ec2_instances = ec2_client.describe_instances()
    table = Table(show_header=True, pad_edge=False, box=box.MINIMAL)
    titles = ['Instance ID', 'VpcID', 'IP Address', 'Operating System', 'Ping Status', 'SSM Agent',
              'Instance State', 'Instance Type', 'Availability Zone', 'Hostname']
    data = []
    output = []
    next_token = ''

    for ec2id in ec2_instances['Reservations']:
        for iid in ec2id['Instances']:
            output = []
            output.append(iid['InstanceId'])
            output.append(iid.get('VpcId'))
            if next_token is not None:
                ssm = ssm_client.describe_instance_information(
                    Filters=[{'Key': 'InstanceIds', 'Values': ['i-02975bc7a520b2434']}], MaxResults=50, NextToken=next_token)
                for ssminfo in ssm['InstanceInformationList']:
                    output.append(ssminfo['IPAddress'])
                    output.append(ssminfo['PlatformName'])
                    output.append(ssminfo['PingStatus'])
                    output.append(str(ssminfo['IsLatestVersion']))
            output.append(str(iid['State']['Name']).capitalize())
            output.append(iid['InstanceType'])
            output.append(iid['Placement']['AvailabilityZone'])
            if 'Tags' in iid:
                for tag in iid['Tags']:
                    if tag['Key'] == 'Name':
                        output.append(tag['Value'])
            data.append(output)

    for column in list(zip(titles)):
        table.add_column(*column)
    for row in list(data):
        table.add_row(*row)
    console.print(table)
    console.print(
        '* ssm-agent column refers to whether the agent is up-to-date')
    console.print('* number of running instances: ',
                  len(ec2_client.describe_instances()['Reservations']))
